# bw_calc

Matrix calculations for Brightway framework.

[![Build Status](https://travis-ci.org/brightway-lca/bw_calc.svg?branch=master)](https://travis-ci.org/brightway-lca/bw_calc) [![Coverage Status](https://coveralls.io/repos/github/brightway-lca/bw_calc/badge.svg?branch=master)](https://coveralls.io/github/brightway-lca/bw_calc?branch=master) [![Build status](https://ci.appveyor.com/api/projects/status/9lfrb8j1ab1dmoti?svg=true)](https://ci.appveyor.com/project/cmutel/bw-calc)
